@@ -77,7 +77,7 @@ static void gff_load_metrics (GnomeFontFace *face, gint glyph);
 static void gff_load_outline (GnomeFontFace *face, gint glyph);
 
 static void gf_pso_sprintf (GnomeFontPsObject * pso, const gchar * format, ...);
-static void gf_pso_ensure_space (GnomeFontPsObject * pso, gint size);
+static void gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject * pso, gint size);
 
 #define GFE_IS_T1_A(e) (((e)->type == GP_FONT_ENTRY_TYPE1) || ((e)->type == GP_FONT_ENTRY_TYPE1_ALIAS))
 #define GFE_IS_TT(e) ((e)->type == GP_FONT_ENTRY_TRUETYPE)
@@ -589,7 +589,7 @@ gnome_font_face_find_closest_from_weight_slant (const guchar *family, GnomeFontW
 			if (entry->type == GP_FONT_ENTRY_ALIAS)
 				entry = ((GPFontEntryAlias *) entry)->ref;
 			dist = abs (weight - entry->Weight) +
-				100 * (italic != (entry->ItalicAngle != 0));
+				100 * (italic != (entry->italic_angle != 0));
 			if (dist < best_dist) {
 				best_dist = dist;
 				best = entry;
@@ -999,11 +999,11 @@ gff_ol2bp (FT_Outline * ol, gdouble transform[])
 
 /* PSO (PostScriptObject stuff */
 
-static void gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso);
-static void gff_pso_ensure_buffer_tt (GnomeFontPsObject *pso);
-static void gff_pso_ensure_buffer_empty (GnomeFontPsObject *pso);
+static void gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso);
+static void gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso);
+static void gnome_font_face_ps_embed_empty (GnomeFontPsObject *pso);
 static void gf_pso_sprintf (GnomeFontPsObject * pso, const gchar * format, ...);
-static void gf_pso_ensure_space (GnomeFontPsObject *pso, gint size);
+static void gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject *pso, gint size);
 
 /*
  * Generates intial PSObject
@@ -1036,7 +1036,7 @@ gnome_font_face_pso_new (GnomeFontFace *face, guchar *residentname)
 		pso->encodedbytes = 1;
 		pso->num_glyphs = 1;
 		pso->glyphs = NULL;
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 	}
 
 	return pso;
@@ -1077,22 +1077,22 @@ gnome_font_face_pso_free (GnomeFontPsObject *pso)
 }
 
 void
-gnome_font_face_pso_ensure_buffer (GnomeFontPsObject *pso)
+gnome_font_face_ps_embed (GnomeFontPsObject *pso)
 {
 	g_return_if_fail (pso != NULL);
 
 	switch (pso->face->entry->type) {
 	case GP_FONT_ENTRY_TYPE1:
 	case GP_FONT_ENTRY_TYPE1_ALIAS:
-		gff_pso_ensure_buffer_t1 (pso);
+		gnome_font_face_ps_embed_t1 (pso);
 		break;
 	case GP_FONT_ENTRY_TRUETYPE:
-		gff_pso_ensure_buffer_tt (pso);
+		gnome_font_face_ps_embed_tt (pso);
 		break;
 	default:
 		g_warning ("file %s: line %d: Unknown face entry type %s:%d",
 			   __FILE__, __LINE__, pso->face->entry->name, pso->face->entry->type);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		break;
 	}
 }
@@ -1100,7 +1100,7 @@ gnome_font_face_pso_ensure_buffer (GnomeFontPsObject *pso)
 #define INT32_LSB(q) ((q)[0] + ((q)[1] << 8) + ((q)[2] << 16) + ((q)[3] << 24))
 
 static void
-gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
+gnome_font_face_ps_embed_t1 (GnomeFontPsObject *pso)
 {
 	GPFontEntryT1 *t1;
 	struct stat st;
@@ -1118,7 +1118,7 @@ gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
 
 	if (!GFF_LOADED (pso->face)) {
 		g_warning ("file %s: line %d: Face: %s: Cannot load face", __FILE__, __LINE__, pso->face->entry->name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 
@@ -1126,19 +1126,19 @@ gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
 	fh = open (t1->pfb.name, O_RDONLY);
 	if (fh < 0) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, t1->pfb.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 	if (fstat (fh, &st) != 0) {
 		g_warning ("file %s: line %d: Cannot fstat font file %s", __FILE__, __LINE__, t1->pfb.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
 	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, t1->pfb.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 
@@ -1155,13 +1155,13 @@ gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
 			gint length, i;
 			if (fbuf[idx] != 0x80) {
 				g_warning ("file %s: line %d: Corrupt %s", __FILE__, __LINE__, t1->pfb.name);
-				gff_pso_ensure_buffer_empty (pso);
+				gnome_font_face_ps_embed_empty (pso);
 				return;
 			}
 			switch (fbuf[idx + 1]) {
 			case 1:
 				length = INT32_LSB (fbuf + idx + 2);
-				gf_pso_ensure_space (pso, length);
+				gnome_font_face_ps_embed_ensure_size (pso, length);
 				idx += 6;
 				memcpy (pso->buf + pso->length, fbuf + idx, length);
 				pso->length += length;
@@ -1169,29 +1169,30 @@ gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
 				break;
 			case 2:
 				length = INT32_LSB (fbuf + idx + 2);
-				gf_pso_ensure_space (pso, length * 3);
+				gnome_font_face_ps_embed_ensure_size (pso, length * 3);
 				idx += 6;
 				for (i = 0; i < length; i++) {
 					pso->buf[pso->length++] = hextab[fbuf[idx] >> 4];
 					pso->buf[pso->length++] = hextab[fbuf[idx] & 15];
 					idx += 1;
-					if ((i & 31) == 31 || i == length - 1) pso->buf[pso->length++] = '\n';
+					if ((i & 31) == 31 || i == length - 1)
+						pso->buf[pso->length++] = '\n';
 				}
 				break;
 			case 3:
 				/* Finished */
-				gf_pso_ensure_space (pso, 1);
+				gnome_font_face_ps_embed_ensure_size (pso, 1);
 				pso->buf[pso->length++] = '\n';
 				idx = st.st_size;
 				break;
 			default:
 				g_warning ("file %s: line %d: Corrupt %s", __FILE__, __LINE__, t1->pfb.name);
-				gff_pso_ensure_buffer_empty (pso);
+				gnome_font_face_ps_embed_empty (pso);
 				return;
 			}
 		}
 	} else {
-		gf_pso_ensure_space (pso, st.st_size);
+		gnome_font_face_ps_embed_ensure_size (pso, st.st_size);
 		memcpy (pso->buf, fbuf, st.st_size);
 		pso->buf[st.st_size] = '\0';
 		pso->length = st.st_size;
@@ -1279,7 +1280,7 @@ gff_pso_ensure_buffer_t1 (GnomeFontPsObject *pso)
  */
 
 static void
-gff_pso_ensure_buffer_tt (GnomeFontPsObject *pso)
+gnome_font_face_ps_embed_tt (GnomeFontPsObject *pso)
 {
 	GPFontEntryTT *tt;
 	struct stat st;
@@ -1297,19 +1298,19 @@ gff_pso_ensure_buffer_tt (GnomeFontPsObject *pso)
 	fh = open (tt->ttf.name, O_RDONLY);
 	if (fh < 0) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, tt->ttf.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 	if (fstat (fh, &st) != 0) {
 		g_warning ("file %s: line %d: Face: %s: Cannot fstat face", __FILE__, __LINE__, tt->ttf.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 	fbuf = mmap (NULL, st.st_size, PROT_READ, MAP_SHARED, fh, 0);
 	close (fh);
 	if ((fbuf == NULL) || (fbuf == (guchar *) -1)) {
 		g_warning ("file %s: line %d: Cannot open font file %s", __FILE__, __LINE__, tt->ttf.name);
-		gff_pso_ensure_buffer_empty (pso);
+		gnome_font_face_ps_embed_empty (pso);
 		return;
 	}
 
@@ -1369,7 +1370,7 @@ gff_pso_ensure_buffer_tt (GnomeFontPsObject *pso)
 		if (!afm) {
 			munmap (fbuf, st.st_size);
 			g_warning ("file %s: line %d: Cannot convert TTF %s to Type1", __FILE__, __LINE__, tt->ttf.name);
-			gff_pso_ensure_buffer_empty (pso);
+			gnome_font_face_ps_embed_empty (pso);
 			return;
 		}
 		/* We take over ownership of afm here (be careful) */
@@ -1458,8 +1459,15 @@ gff_pso_ensure_buffer_tt (GnomeFontPsObject *pso)
 	}
 }
 
+/**
+ * gnome_font_face_ps_embed_empty:
+ * @pso: 
+ * 
+ * We use this function when something goes wrong but we still want to
+ * get some output printed.
+ **/
 static void
-gff_pso_ensure_buffer_empty (GnomeFontPsObject *pso)
+gnome_font_face_ps_embed_empty (GnomeFontPsObject *pso)
 {
 	pso->length = 0;
 
@@ -1504,7 +1512,7 @@ gf_pso_sprintf (GnomeFontPsObject * pso, const gchar * format, ...)
 	va_end (arguments);
 
 	len = strlen (text);
-	gf_pso_ensure_space (pso, len);
+	gnome_font_face_ps_embed_ensure_size (pso, len);
 	memcpy (pso->buf + pso->length, text, len);
 	pso->length += len;
 	g_free (text);
@@ -1514,14 +1522,15 @@ gf_pso_sprintf (GnomeFontPsObject * pso, const gchar * format, ...)
 }
 
 static void
-gf_pso_ensure_space (GnomeFontPsObject *pso, gint size)
+gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject *pso, gint size)
 {
 	if (pso->length + size > pso->bufsize) {
 		if (pso->bufsize < 1) {
 			pso->bufsize = MAX (size, 1024);
 			pso->buf = g_new (guchar, pso->bufsize);
 		} else {
-			while (pso->length + size > pso->bufsize) pso->bufsize <<= 1;
+			while (pso->length + size > pso->bufsize)
+				pso->bufsize <<= 1;
 			pso->buf = g_renew (guchar, pso->buf, pso->bufsize);
 		}
 	}
@@ -1617,9 +1626,7 @@ gnome_font_face_is_italic (GnomeFontFace * face)
 		e = face->entry;
 	}
 
-	return e->ItalicAngle;
-
-	return FALSE;
+	return (e->italic_angle = 0.0 ? TRUE : FALSE);
 }
 
 gboolean
