@@ -306,8 +306,8 @@ gnome_print_pdf_construct (GnomePrintContext *ctx)
 	ret += gnome_print_transport_open (ctx->transport);
 	g_return_val_if_fail (ret >= 0, ret);
 
-	/* Chema Foo */
-	/* Set bbox to emty practical infinity */
+        /* FIXME: if this is the logical area, we know it from the paper size and margins, fix. (Chema) */	
+	/* Set bbox to empty practical infinity */
 	pdf->bbox.x0 = 0.0;
 	pdf->bbox.y0 = 0.0;
 	pdf->bbox.x1 = 210 * 72.0 / 25.4;
@@ -327,7 +327,6 @@ gnome_print_pdf_construct (GnomePrintContext *ctx)
 			pdf->bbox.y0 = 0.0;
 		}
 	}
-	/* Chema Foo */
 
 	gnome_print_pdf_fprintf (pdf, "%cPDF-1.3" EOL, '%');
 	gnome_print_pdf_fprintf (pdf, "%c%c%c%c%c" EOL, '%',
@@ -796,26 +795,37 @@ gnome_print_pdf_page_write_resources (GnomePrintPdf *pdf, GnomePrintPdfPage *pag
 static gint
 gnome_print_pdf_showpage (GnomePrintContext *pc)
 {
+	GnomePrintPdfPage *page;
 	GnomePrintPdf *pdf;
 	gint ret = 0;
 
 	pdf = GNOME_PRINT_PDF (pc);
 
-	gnome_print_pdf_graphic_mode_set (pdf, PDF_GRAPHIC_MODE_GRAPHICS);
+	g_return_val_if_fail (pdf != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
+	g_return_val_if_fail (pdf->pages != NULL, GNOME_PRINT_ERROR_NOPAGE);
+	g_return_val_if_fail (pdf->pages->data != NULL, GNOME_PRINT_ERROR_UNKNOWN);
+
+	page = pdf->pages->data;
+
+	g_return_val_if_fail (page->shown == FALSE, GNOME_PRINT_ERROR_UNKNOWN);
+		
+	gnome_print_pdf_page_write_contents  (pdf, page);
+	gnome_print_pdf_page_write_resources (pdf, page);
 	
-	if (pdf->pages) {
-		GnomePrintPdfPage *page = pdf->pages->data;
-		page->shown = TRUE;
-	}
+	page->shown = TRUE;
+	g_free (page->stream);
+	page->stream = NULL;
+	page->stream_used = 0;
+	page->stream_allocated = 0;
+	g_list_free (page->images);
+
+	gnome_print_pdf_graphic_mode_set (pdf, PDF_GRAPHIC_MODE_GRAPHICS);
 	
 	pdf->selected_font    = NULL;
 	pdf->color_set_fill   = FALSE;
 	pdf->color_set_stroke = FALSE;
 	
-	/* Write contents */
-	gnome_print_pdf_page_write_contents  (pdf, pdf->pages->data);
-	gnome_print_pdf_page_write_resources (pdf, pdf->pages->data);
-
+		
 	g_return_val_if_fail (ret >= 0, ret);
 	
 	return GNOME_PRINT_OK;
@@ -833,16 +843,14 @@ gint
 gnome_print_pdf_object_new (GnomePrintPdf *pdf)
 {
 	GnomePrintPdfObject *object;
-	static gint num = 1;
 
 	object = g_new (GnomePrintPdfObject, 1);
-	object->number = num;
 	object->offset = 0;
+	object->number = g_list_length (pdf->objects) + 1;
 
 	pdf->objects = g_list_prepend (pdf->objects, object);
-	num ++;
 
-	return num - 1;
+	return object->number;
 }
 
 /**
@@ -1115,6 +1123,8 @@ gnome_print_pdf_close_write_last_objects (GnomePrintPdf *pdf)
 				 object_num_info,
 				 id, id, xref_offset,
 				 '%', '%');
+	g_free (id);
+	
 	return ret;
 }
 
@@ -1139,6 +1149,8 @@ gnome_print_pdf_close (GnomePrintContext *pc)
 
 	ret += gnome_print_pdf_close_write_last_objects (pdf);
 
+ 	gnome_print_transport_close (pc->transport);
+	g_object_unref (G_OBJECT (pc->transport));
 	pc->transport = NULL;
  	
 	return GNOME_PRINT_OK;
@@ -1519,15 +1531,10 @@ gnome_print_pdf_set_font_real (GnomePrintPdf *pdf, const GnomeFont *gnome_font)
 	else if (face->entry->type == GP_FONT_ENTRY_TRUETYPE)
 		font->is_type_1 = FALSE;
 	else {
-		g_warning ("We only support True Type and Type 1 font for now");
+		g_warning ("We only support True Type and Type 1 fonts for now");
 		return GNOME_PRINT_ERROR_UNKNOWN;
 	}
 
-	/* FIXME: I don't know why we are unrefing the font but it works
-	 * Where is its corresponding ref? (Chema)
-	 */
-	gnome_font_unref (gnome_font);
-	
 	/* Add it to the list of fonts of this job */
 	pdf->fonts = g_list_prepend (pdf->fonts, font);
 
@@ -1741,7 +1748,7 @@ gnome_print_pdf_print_sized (GnomePrintPdf *pdf, const char *content, gint len)
 static gint
 gnome_print_pdf_page_fprintf (GnomePrintPdf *pdf, const char *format, ...)
 {
-	static gint grow_size = GNOME_PRINT_PDF_INITIAL_BUFFER_SIZE;
+	gint grow_size = GNOME_PRINT_PDF_INITIAL_BUFFER_SIZE;
 	GnomePrintPdfPage *page;
  	va_list arguments;
  	gchar *text;
@@ -1760,11 +1767,14 @@ gnome_print_pdf_page_fprintf (GnomePrintPdf *pdf, const char *format, ...)
 	/* Write it */
 	len = strlen (text);
 	page = pdf->pages->data;
-	while ((page->stream_used + len + 10) > page->stream_allocated) {
-		page->stream_allocated += grow_size;
-		grow_size <<= 1;
+	if ((page->stream_used + len + 1) > page->stream_allocated) {
+		while ((page->stream_used + len) > page->stream_allocated) {
+			page->stream_allocated += grow_size;
+			grow_size <<= 1;
+		}
+		page->stream = g_realloc (page->stream, page->stream_allocated);
 	}
-	page->stream = g_realloc (page->stream, page->stream_allocated);
+
 	memcpy (page->stream + page->stream_used, text, len * sizeof (gchar));
 	page->stream_used += len;
 	page->stream [page->stream_used] = 0;
