@@ -364,6 +364,7 @@ gpa_model_new_from_tree (xmlNodePtr tree)
 	model = g_hash_table_lookup (modeldict, model_id);
 	if (model != NULL) {
 		gpa_node_ref (GPA_NODE (model));
+		xmlFree (model_id);
 		return GPA_NODE (model);
 	}
 
@@ -554,6 +555,8 @@ gpa_model_load (GPAModel *model)
 	model_id = xmlGetProp (root, "Id");
 	if (!model_id || !GPA_NODE_ID_COMPARE (model, model_id)) {
 		g_warning ("Missing \"Id\" node in model description %s", GPA_NODE_ID (model));
+		if (model_id)
+			xmlFree (model_id);
 		return FALSE;
 	}
 
@@ -581,6 +584,7 @@ gpa_model_load (GPAModel *model)
 		if (options)
 			gpa_node_unref (GPA_NODE (options));
 		
+		xmlFree (model_id);
 		return FALSE;
 	}
 	
